package skeleton;

/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

/**
 * 
 * @author szymon
 */
public abstract class DataFetcher {
    private static final Object lock = new Object();
    private Response r;
    private String parameters;

    /**
     * Method that is fired before real data aquisition starts.
     * It should prepare field for data aquisition - for instance
     * it can create GUI interface.
     */
    public abstract void start();

    /**
     * Methd that should inform if data acquisition is still running, or if it's finished.
     * In GUI isVisible method can be invoked inside this method, and its result returned
     *
     * @return true or false depending on the state of data acquisition process
     */
    public abstract boolean running();

    /**
     * Method that releases lock at the end of data acquisition, so that a thread
     * waiting for that can
     * send data to Prolog. If this method is overriden in derived class at the very end
     * super.end() should be invoked anyway to release a lock.
     */
    public void end(){
        synchronized(lock){
            lock.notify();
        }
    }

    public String getParameters() {
        return parameters;
    }

    public void setParameters(String parameters) {
        this.parameters = parameters;
    }

    
    /**
     *
     * @return data acquired wrapped in Response object
     */
    public final Response getResponse(){return r;}
    /**
     *
     * @param r data acquired wrapped in Response object
     */
    public final void setResponse(Response r){this.r =r;}
    /**
     *
     * @return a lock for thread that waits for data acquisition to 
     */
    public final Object getLock(){return lock;}
}
